Class: Tupelo::Client::NullTupleStore
- Includes:
- Enumerable
- Defined in:
- lib/tupelo/client/tuplestore.rb
Overview
Tuplestore that stores nothing. Very efficient for large stores! Useful for clients that don’t need to take or read the stored tuples. The write, pulse, and blocking read operations all work correctly. The client is essentially a pub/sub client, then. See the –pubsub switch in tup for an example.
Instance Method Summary collapse
- #clear ⇒ Object
- #delete_once ⇒ Object
- #each ⇒ Object
- #find_distinct_matches_for ⇒ Object
- #find_match_for ⇒ Object
- #insert ⇒ Object
Instance Method Details
#clear ⇒ Object
47 |
# File 'lib/tupelo/client/tuplestore.rb', line 47 def clear; end |
#delete_once ⇒ Object
43 |
# File 'lib/tupelo/client/tuplestore.rb', line 43 def delete_once(*); end |
#each ⇒ Object
42 |
# File 'lib/tupelo/client/tuplestore.rb', line 42 def each(*); end |
#find_distinct_matches_for ⇒ Object
45 |
# File 'lib/tupelo/client/tuplestore.rb', line 45 def find_distinct_matches_for(*); raise; end |
#find_match_for ⇒ Object
46 |
# File 'lib/tupelo/client/tuplestore.rb', line 46 def find_match_for(*); raise; end |
#insert ⇒ Object
44 |
# File 'lib/tupelo/client/tuplestore.rb', line 44 def insert(*); self; end |